==> create-fly-1.21.10-6.0.8-5-sources.jar: com/zurrtum/create/content/logistics/chute/ChuteItem.java <==
package com.zurrtum.create.content.logistics.chute;

import com.zurrtum.create.foundation.block.ProperWaterloggedBlock;
import net.minecraft.class_1269;
import net.minecraft.class_1747;
import net.minecraft.class_1750;
import net.minecraft.class_1937;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_2680;

public class ChuteItem extends class_1747 {

    public ChuteItem(class_2248 p_i48527_1_, class_1793 p_i48527_2_) {
        super(p_i48527_1_, p_i48527_2_);
    }

    @Override
    public class_1269 method_7712(class_1750 context) {
        class_2350 face = context.method_8038();
        class_2338 placedOnPos = context.method_8037().method_10093(face.method_10153());
        class_1937 world = context.method_8045();
        class_2680 placedOnState = world.method_8320(placedOnPos);

        if (!AbstractChuteBlock.isChute(placedOnState) || context.method_8046())
            return super.method_7712(context);
        if (face.method_10166().method_10178())
            return super.method_7712(context);

        class_2338 correctPos = context.method_8037().method_10084();

        class_2680 blockState = world.method_8320(correctPos);
        if (blockState.method_45474())
            context = class_1750.method_16355(context, correctPos, face);
        else {
            if (!(blockState.method_26204() instanceof ChuteBlock block) || world.method_8608())
                return class_1269.field_5814;
            if (block.getFacing(blockState) == class_2350.field_11033) {
                world.method_8501(
                    correctPos, ProperWaterloggedBlock.withWater(
                        world,
                        block.updateChuteState(blockState.method_11657(ChuteBlock.FACING, face), world.method_8320(correctPos.method_10084()), world, correctPos),
                        correctPos
                    )
                );
                return class_1269.field_5812;
            }
            return class_1269.field_5814;
        }

        return super.method_7712(context);
    }

}

==> create-fly-1.21.11-pre1-6.0.8-1-sources.jar: com/zurrtum/create/content/logistics/chute/ChuteItem.java <==
package com.zurrtum.create.content.logistics.chute;

import com.zurrtum.create.foundation.block.ProperWaterloggedBlock;
import net.minecraft.class_1269;
import net.minecraft.class_1747;
import net.minecraft.class_1750;
import net.minecraft.class_1937;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_2680;

public class ChuteItem extends class_1747 {

    public ChuteItem(class_2248 p_i48527_1_, class_1793 p_i48527_2_) {
        super(p_i48527_1_, p_i48527_2_);
    }

    @Override
    public class_1269 method_7712(class_1750 context) {
        class_2350 face = context.method_8038();
        class_2338 placedOnPos = context.method_8037().method_10093(face.method_10153());
        class_1937 world = context.method_8045();
        class_2680 placedOnState = world.method_8320(placedOnPos);

        if (!AbstractChuteBlock.isChute(placedOnState) || context.method_8046())
            return super.method_7712(context);
        if (face.method_10166().method_10178())
            return super.method_7712(context);

        class_2338 correctPos = context.method_8037().method_10084();

        class_2680 blockState = world.method_8320(correctPos);
        if (blockState.method_45474())
            context = class_1750.method_16355(context, correctPos, face);
        else {
            if (!(blockState.method_26204() instanceof ChuteBlock block) || world.method_8608())
                return class_1269.field_5814;
            if (block.getFacing(blockState) == class_2350.field_11033) {
                world.method_8501(
                    correctPos, ProperWaterloggedBlock.withWater(
                        world,
                        block.updateChuteState(
                            blockState.method_11657(ChuteBlock.FACING, face),
                            world.method_8320(correctPos.method_10084()),
                            world,
                            correctPos
                        ),
                        correctPos
                    )
                );
                return class_1269.field_5812;
            }
            return class_1269.field_5814;
        }

        return super.method_7712(context);
    }

}
